==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaChannelListBuilder.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaChannelListBuilder extends KafkaChannelListFluentImpl<KafkaChannelListBuilder> implements VisitableBuilder<KafkaChannelList,KafkaChannelListBuilder> {

    KafkaChannelListFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaChannelListBuilder() { 
        this(true);
    }


    public KafkaChannelListBuilder(Boolean validationEnabled) { 
        this(new KafkaChannelList(), validationEnabled);
    }


    public KafkaChannelListBuilder(KafkaChannelListFluent<?> fluent) { 
        this(fluent, true);
    }


    public KafkaChannelListBuilder(KafkaChannelListFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new KafkaChannelList(), validationEnabled);
    }


    public KafkaChannelListBuilder(KafkaChannelListFluent<?> fluent,KafkaChannelList instance) { 
        this(fluent, instance, true);
    }


    public KafkaChannelListBuilder(KafkaChannelListFluent<?> fluent,KafkaChannelList instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public KafkaChannelListBuilder(KafkaChannelList instance) { 
        this(instance,true);
    }


    public KafkaChannelListBuilder(KafkaChannelList instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public KafkaChannelList build() {
        KafkaChannelList buildable = new KafkaChannelList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        KafkaChannelListBuilder that = (KafkaChannelListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaChannelListBuilder.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaChannelListBuilder extends KafkaChannelListFluentImpl<KafkaChannelListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<KafkaChannelList,KafkaChannelListBuilder> {

    KafkaChannelListFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaChannelListBuilder() {
        this(true);
    }

    public KafkaChannelListBuilder(Boolean validationEnabled) {
        this(new KafkaChannelList(), validationEnabled);
    }

    public KafkaChannelListBuilder(KafkaChannelListFluent<?> fluent) {
        this(fluent, true);
    }

    public KafkaChannelListBuilder(KafkaChannelListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new KafkaChannelList(), validationEnabled);
    }

    public KafkaChannelListBuilder(KafkaChannelListFluent<?> fluent,KafkaChannelList instance) {
        this(fluent, instance, true);
    }

    public KafkaChannelListBuilder(KafkaChannelListFluent<?> fluent,KafkaChannelList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public KafkaChannelListBuilder(KafkaChannelList instance) {
        this(instance,true);
    }

    public KafkaChannelListBuilder(KafkaChannelList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.EditableKafkaChannelList build() {
        EditableKafkaChannelList buildable = new EditableKafkaChannelList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        KafkaChannelListBuilder that = (KafkaChannelListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
